/*
 * Copyright (c) 2011 ScientiaMobile srl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.SortedSet;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: KDDIMatcher.java 1117 2009-03-20 10:07:30Z filippo.deluca $
 */
public class KDDIMatcher extends AbstractMatcher {

	public KDDIMatcher(Handler handler) {
		super(handler);
	}

	/**
	 * if UA starts with "KDDI/", apply RIS(SS) Otherwise apply RIS(FS)
	 */
	protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
			String userAgent) {
		if (userAgent.startsWith("KDDI/")) {
			int tollerance = StringUtils.secondSlash(userAgent);

			if (logger.isDebugEnabled()) {
				logger.debug("Applying RIS(SS) UA: " + userAgent);
			}

			return StringUtils.risMatch(userAgentsSet, userAgent, tollerance);
		}

		return super.lookForMatchingUserAgent(userAgentsSet, userAgent);
	}

	protected String applyRecoveryMatch(WURFLRequest request,
			FilteredDevices filteredDevices) {
		return "opwv_v62_generic";
	}
}
