/*
 * Copyright (c) 2011 ScientiaMobile srl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import org.apache.commons.lang.text.StrBuilder;

/**
 * Generic User-Agent consistency exception.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: UserAgentConsistencyException.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public abstract class UserAgentConsistencyException extends
		DeviceConsistencyException {

	/** Serial */
	private static final long serialVersionUID = 10L;

	/** User-Agent source of this exception */
	private String userAgent;

	/**
	 * Build UserAgentConsistencyException by device, userAgent and message.
	 * 
	 * @param device The device source of this exception.
	 * @param userAgent The user-agent causes consistency exception.
	 * @param message The message to display.
	 */
	public UserAgentConsistencyException(ModelDevice device, String userAgent,
			String message) {
		super(device, message);

		this.userAgent = userAgent;

	}

	/**
	 * Build UserAgentConsistencyException by device and userAgent.
	 * 
	 * @param device The device source of this exception.
	 * @param userAgent The user-agent causes consistency exception.
	 */
	public UserAgentConsistencyException(ModelDevice device, String userAgent) {
		super(device, new StrBuilder("Device: ").append(device.getID()).append(
				" user-agent: ").append(userAgent).append(
				" consistency exception").toString());

		this.userAgent = userAgent;
	}

	/**
	 * The inconsistent user-agent.
	 * 
	 * @return User-Agent string causes this exception.
	 */
	public String getUserAgent() {
		return userAgent;
	}

}
