/*
 * Copyright (c) 2011 ScientiaMobile srl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

/**
 * This is a mutable {@link WURFLModel} interface. All classes need to modify
 * the model must referencing this interface.
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: WURFLAccessibleModel.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public interface WURFLAccessibleModel extends WURFLModel {

	/**
	 * Applies a patch to model runtime.
	 * 
	 * @param patch
	 *            The resource represents patch.
	 */
	public void applyPatch(WURFLResource patch);

	/**
	 * Applies several patches to model runtime.
	 * 
	 * @param patches
	 *            The resources represent patches.
	 */
	public void applyPatches(WURFLResources patches);

	// Event handling *****************************************************

	/**
	 * Add a {@link WURFLModelListener} observe this model.
	 * 
	 * @param The
	 *            listener to add.
	 */
	public void addModelListener(WURFLModelListener listener);

	/**
	 * Remove a {@link WURFLModelListener} observing this model. If the listener
	 * are not observing this model then the operation is ignored.
	 * 
	 * @param The
	 *            listener to remove.
	 */
	public void removeModelListener(WURFLModelListener listener);
}
