/*
 * Copyright (c) 2011 ScientiaMobile srl
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * Refer to the COPYING file distributed with this package.
 */
package net.sourceforge.wurfl.core.resource;

import net.sourceforge.wurfl.core.WURFLRuntimeException;

/**
 * WURFL generic consistency exception.
 * 
 * <p>
 * This exception is thrown when the WURFL model contains inconsistent data.
 * </p>
 * 
 * @author WURFL-PRO SRL, Rome, Italy
 * @version $Id: WURFLConsistencyException.java 1045 2009-03-09 15:52:53Z filippo.deluca $
 */
public abstract class WURFLConsistencyException extends WURFLRuntimeException {

	/** serial */
	private static final long serialVersionUID = 10L;
	
	/**
	 * Default constructor.
	 */
	public WURFLConsistencyException() {
		super("WURFL consistency exception");
	}

	/**
	 * Build WURFLConsistencyException by Throwable.
	 * 
	 * @param cause This exception cause.
	 */
	public WURFLConsistencyException(Throwable cause) {
		super("WURFL consistency exception", cause);
	}

	/**
	 * Build WURFLConsistencyException by displaying message.
	 * 
	 * @param message The message to display.
	 */
	public WURFLConsistencyException(String message) {
		super(message);
	}
	
	/**
	 * Build WURFLConsistencyException by Throwable and message.
	 * 
	 * @param cause This exception cause.
	 * @param message The message to display.
	 */
	public WURFLConsistencyException(String message, Throwable cause) {
		super(message, cause);
	}
}
